<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>LocaleConfig</name>
    <message>
        <location filename="../localeconfig.ui" line="31"/>
        <source>Re&amp;gion:</source>
        <translation>&amp;Oblast:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="60"/>
        <source>De&amp;tailed Settings</source>
        <translation>Podrobná nas&amp;tavení</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="78"/>
        <source>&amp;Numbers:</source>
        <translation>Čí&amp;sla:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="107"/>
        <source>&amp;Time:</source>
        <translation>Č&amp;as:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="136"/>
        <source>Currenc&amp;y:</source>
        <translation>&amp;Měna:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="165"/>
        <source>Measurement &amp;Units:</source>
        <translation>&amp;Jednotky měření:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="194"/>
        <source>Co&amp;llation and Sorting:</source>
        <translation>Sr&amp;ovnávání a řazení:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="226"/>
        <source>Examples</source>
        <translation>Příklady</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="238"/>
        <source>Numbers:</source>
        <translation>Čísla:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="258"/>
        <source>Time:</source>
        <translation>Čas:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="289"/>
        <source>Currency:</source>
        <translation>Měna:</translation>
    </message>
    <message>
        <location filename="../localeconfig.ui" line="309"/>
        <source>Measurement Units:</source>
        <translation>Jednotky měření:</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="164"/>
        <source>Unset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="226"/>
        <source>Current: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="370"/>
        <source>Format Settings Changed</source>
        <translation>Nastavení formátu změněno</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="371"/>
        <source>Do you want to save your changes? They will take effect the next time you log in.</source>
        <translation>Chcete změny uložit? Projeví se po příštím přihlášení.</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="518"/>
        <source>Imperial UK</source>
        <translation>Imperiální UK</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="522"/>
        <source>Imperial US</source>
        <translation>Imperiální US</translation>
    </message>
    <message>
        <location filename="../localeconfig.cpp" line="526"/>
        <source>Metric</source>
        <translation>Metrické</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>LXQt Locale Configuration</source>
        <translation>Místní nastavení pro LXQt</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Locale Settings</source>
        <translation>Místní nastavení</translation>
    </message>
</context>
</TS>
